==> dcp-client-0.36.0-sources.jar: com/couchbase/client/dcp/message/DcpStreamEndMessage.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.dcp.message;

import com.couchbase.client.dcp.deps.io.netty.buffer.ByteBuf;

import static com.couchbase.client.dcp.message.MessageUtil.DCP_STREAM_END_OPCODE;

public enum DcpStreamEndMessage {
  ;

  public static boolean is(final ByteBuf buffer) {
    return buffer.getByte(0) == MessageUtil.MAGIC_REQ && buffer.getByte(1) == DCP_STREAM_END_OPCODE;
  }

  public static int vbucket(final ByteBuf buffer) {
    return MessageUtil.getVbucket(buffer);
  }

  public static StreamEndReason reason(final ByteBuf buffer) {
    int flags = MessageUtil.getExtras(buffer).getInt(0);
    return StreamEndReason.of(flags);
  }

  public static String getReasonAsString(final ByteBuf buffer) {
    int reasonCode = MessageUtil.getExtras(buffer).getInt(0);
    try {
      return StreamEndReason.of(reasonCode).name();
    } catch (IllegalArgumentException e) {
      return String.valueOf(reasonCode);
    }
  }
}

==> dcp-client-0.44.0-sources.jar: com/couchbase/client/dcp/message/DcpStreamEndMessage.java <==
/*
 * Copyright (c) 2016 Couchbase, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.couchbase.client.dcp.message;

import com.couchbase.client.core.deps.io.netty.buffer.ByteBuf;

import static com.couchbase.client.dcp.message.MessageUtil.DCP_STREAM_END_OPCODE;

public enum DcpStreamEndMessage {
  ;

  public static boolean is(final ByteBuf buffer) {
    return buffer.getByte(0) == MessageUtil.MAGIC_REQ && buffer.getByte(1) == DCP_STREAM_END_OPCODE;
  }

  public static int vbucket(final ByteBuf buffer) {
    return MessageUtil.getVbucket(buffer);
  }

  public static StreamEndReason reason(final ByteBuf buffer) {
    int flags = MessageUtil.getExtras(buffer).getInt(0);
    return StreamEndReason.of(flags);
  }

  public static String getReasonAsString(final ByteBuf buffer) {
    int reasonCode = MessageUtil.getExtras(buffer).getInt(0);
    try {
      return StreamEndReason.of(reasonCode).name();
    } catch (IllegalArgumentException e) {
      return String.valueOf(reasonCode);
    }
  }
}
